@@ -485,8 +485,8 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
             pos = highS->testHighscore();  // check highscore entry
             if (pos != -1)
             {
+              highE->position = pos;
               status = 12;
-              highE->writeHighscore(pos);
               highE->show();
             }
             else
@@ -751,7 +751,7 @@ char Highscore::testHighscore()    // test new highscore entry
 {
   int zeit;
   char i;
-  zeit = topW->sekunden/2;
+  zeit = highE->sec;
   loadHighscore();
   for (i = 0; i <= 49; i++)
   {
@@ -764,14 +764,14 @@ char Highscore::testHighscore()    // test new highscore entry
   return -1;
 }
 
-void HighscoreEdit::writeHighscore(char pos)  // write highscore file
+void HighscoreEdit::writeHighscore()  // write highscore file
 {
   char i;
   int zeit;
   FILE* stream;
   char tempstr[50];
   char playn[50][50];
-  zeit = topW->sekunden/2;
+  zeit = sec;
   stream = fopen(home_path+"kwappen/kwappen_highscore.txt", "rt");
   if (! stream)  return;
   for(i = 0; i < 50; i++)          // read player names from file
@@ -782,13 +782,13 @@ void HighscoreEdit::writeHighscore(char pos)  // write highscore file
   fclose(stream);
   stream = fopen(home_path+"kwappen/kwappen_highscore.txt", "wt");
   if (! stream)  return;
-  for(i=0; i<pos; i++)             // write highscore file
+  for(i = 0; i < position; i++)             // write highscore file
   {
     fputs(playn[i], stream);
   }
   sprintf(tempstr,"%5u : %s\n", zeit, playerName);
   fputs(tempstr,stream);
-  for(i=pos+1; i < 50; i++)
+  for(i = position + 1; i < 50; i++)
   { if (highS->score[i-1] == 99999)
     {
       fputs("XXX : ---\n", stream);
@@ -850,6 +850,7 @@ void HighscoreEdit::getHighscore()   // input name highscore of player
 {
   strcpy(playerName, highscoreentry->text());
   highE->hide();
+  writeHighscore();
   topW->status = -1;
   topW->start_turm();
   topW->repaint();
